pub enum AdapterResult {
PlanServe {
output: Box<PlanServeResult>,
},
RenderServe {
output: Box<RenderServeResult>,
},
}Expand description
The successful result of an AdapterRequest, tagged by the operation it
answers.
Variants
PlanServe
The planned topology from a PlanServe request.
Fields

output: Box<PlanServeResult>RenderServe
The rendered process invocations from a RenderServe request.
Fields

output: Box<RenderServeResult>Trait Implementations
Sourceimpl Clone for AdapterResult
impl Clone for AdapterResult
Sourcefn clone(&self) -> AdapterResult
fn clone(&self) -> AdapterResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdapterResult
impl Debug for AdapterResult
Sourceimpl<'de> Deserialize<'de> for AdapterResult
impl<'de> Deserialize<'de> for AdapterResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdapterResult
impl JsonSchema for AdapterResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdapterResult
impl PartialEq for AdapterResult
Sourcefn eq(&self, other: &AdapterResult) -> bool
fn eq(&self, other: &AdapterResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AdapterResult
impl Serialize for AdapterResult
impl StructuralPartialEq for AdapterResult