EvalDefinitionInput

Enum EvalDefinitionInput 

pub enum EvalDefinitionInput {
    OpenAiSmoke {
        prompt: String,
        max_tokens: u32,
        timeout_seconds: u64,
    },
    LmEval {
        task: String,
        dataset: Option<String>,
        split: Option<String>,
        limit: Option<u32>,
        few_shot: Option<u32>,
        seed: Option<u64>,
        max_tokens: Option<u32>,
        concurrency: Option<u32>,
        metric: String,
        threshold: f64,
        timeout_seconds: u64,
    },
}
The measurement an Eval client runs against the workload endpoint.

Variants



OpenAiSmoke

A single-prompt liveness check.

Fields

prompt: String
max_tokens: u32
timeout_seconds: u64


LmEval

An lm-eval task run with a pass threshold on the chosen metric.

Fields

task: String
dataset: Option<String>
limit: Option<u32>
few_shot: Option<u32>
seed: Option<u64>
max_tokens: Option<u32>
concurrency: Option<u32>
metric: String
threshold: f64
timeout_seconds: u64