pub struct AdapterError {
pub code: AdapterErrorCode,
pub message: String,
}Expand description
A structured rejection an integration returns in an AdapterResponse::Error.
Fields
code: AdapterErrorCodemessage: StringTrait Implementations
Sourceimpl Clone for AdapterError
impl Clone for AdapterError
Sourcefn clone(&self) -> AdapterError
fn clone(&self) -> AdapterError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdapterError
impl Debug for AdapterError
Sourceimpl<'de> Deserialize<'de> for AdapterError
impl<'de> Deserialize<'de> for AdapterError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AdapterError
Sourceimpl JsonSchema for AdapterError
impl JsonSchema for AdapterError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AdapterError
impl PartialEq for AdapterError
Sourcefn eq(&self, other: &AdapterError) -> bool
fn eq(&self, other: &AdapterError) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AdapterError
impl Serialize for AdapterError
impl StructuralPartialEq for AdapterError