pub struct AuxiliaryModelInput {
pub kind: AuxiliaryModelKind,
pub model: ServeModelInput,
}Expand description
A logical auxiliary weight identity supplied during serving planning and rendering: its governed kind plus the referenced logical model ([[RFC-0003:C-SERVE-AUXILIARY-MODELS]]).
Fields
kind: AuxiliaryModelKindmodel: ServeModelInputTrait Implementations
Sourceimpl Clone for AuxiliaryModelInput
impl Clone for AuxiliaryModelInput
Sourcefn clone(&self) -> AuxiliaryModelInput
fn clone(&self) -> AuxiliaryModelInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuxiliaryModelInput
impl Debug for AuxiliaryModelInput
Sourceimpl<'de> Deserialize<'de> for AuxiliaryModelInput
impl<'de> Deserialize<'de> for AuxiliaryModelInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AuxiliaryModelInput
Sourceimpl JsonSchema for AuxiliaryModelInput
impl JsonSchema for AuxiliaryModelInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AuxiliaryModelInput
impl PartialEq for AuxiliaryModelInput
Sourceimpl Serialize for AuxiliaryModelInput
impl Serialize for AuxiliaryModelInput
impl StructuralPartialEq for AuxiliaryModelInput