pub struct AuxiliaryModelLocator {
pub kind: AuxiliaryModelKind,
pub locator: String,
}Expand description
A machine-resolved auxiliary weight locator on a model-rank allocation ([[RFC-0003:C-SERVE-AUXILIARY-MODELS]]).
Fields
kind: AuxiliaryModelKindlocator: StringTrait Implementations
Sourceimpl Clone for AuxiliaryModelLocator
impl Clone for AuxiliaryModelLocator
Sourcefn clone(&self) -> AuxiliaryModelLocator
fn clone(&self) -> AuxiliaryModelLocator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuxiliaryModelLocator
impl Debug for AuxiliaryModelLocator
Sourceimpl<'de> Deserialize<'de> for AuxiliaryModelLocator
impl<'de> Deserialize<'de> for AuxiliaryModelLocator
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AuxiliaryModelLocator
Sourceimpl JsonSchema for AuxiliaryModelLocator
impl JsonSchema for AuxiliaryModelLocator
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AuxiliaryModelLocator
impl PartialEq for AuxiliaryModelLocator
Sourceimpl Serialize for AuxiliaryModelLocator
impl Serialize for AuxiliaryModelLocator
impl StructuralPartialEq for AuxiliaryModelLocator