pub struct BenchAgenticBranchStats {
pub children_spawned: u64,
pub children_completed: u64,
pub children_errored: u64,
pub children_truncated: u64,
pub children_delayed: u64,
pub parents_suspended: u64,
pub parents_resumed: u64,
pub parents_failed_due_to_child_error: u64,
pub joins_suppressed: u64,
}Fields
children_spawned: u64children_completed: u64children_errored: u64children_truncated: u64children_delayed: u64parents_suspended: u64parents_resumed: u64parents_failed_due_to_child_error: u64joins_suppressed: u64Trait Implementations
Sourceimpl Clone for BenchAgenticBranchStats
impl Clone for BenchAgenticBranchStats
Sourcefn clone(&self) -> BenchAgenticBranchStats
fn clone(&self) -> BenchAgenticBranchStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchAgenticBranchStats
impl Debug for BenchAgenticBranchStats
Sourceimpl<'de> Deserialize<'de> for BenchAgenticBranchStats
impl<'de> Deserialize<'de> for BenchAgenticBranchStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchAgenticBranchStats
Sourceimpl JsonSchema for BenchAgenticBranchStats
impl JsonSchema for BenchAgenticBranchStats
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchAgenticBranchStats
impl PartialEq for BenchAgenticBranchStats
Sourceimpl Serialize for BenchAgenticBranchStats
impl Serialize for BenchAgenticBranchStats
impl StructuralPartialEq for BenchAgenticBranchStats