pub struct BenchAgenticCatalogInput {Show 40 fields
pub repository: String,
pub revision: String,
pub filename: String,
pub sha256: String,
pub cache_path: Option<PathBuf>,
pub cache_state: Option<BenchDatasetCacheState>,
pub trace_count: u32,
pub approximate_bytes: u64,
pub license: String,
pub source_format: String,
pub aiperf_loader: String,
pub materialization_identity: String,
pub scenario: String,
pub concurrency_semantics: String,
pub replay_semantics: String,
pub cache_bust: String,
pub trajectory_start_min: f64,
pub trajectory_start_max: f64,
pub global_idle_gap_cap_seconds: f64,
pub trace_idle_gap_cap_seconds: f64,
pub cache_warmup_requests_per_lane: u64,
pub warmup_grace_seconds: u64,
pub dataset_configuration_timeout_seconds: u64,
pub service_profile_configuration_timeout_seconds: u64,
pub default_duration_seconds: u64,
pub minimum_duration_seconds: u64,
pub failure_threshold: f64,
pub dataset_entries: u32,
pub streaming: bool,
pub ignore_eos: bool,
pub use_server_token_count: bool,
pub gpu_telemetry: bool,
pub server_metric_slice_seconds: u64,
pub required_artifacts: Vec<String>,
pub unavailable_dimensions: Vec<String>,
pub inferencex_repository: String,
pub inferencex_revision: String,
pub inferencex_reference: String,
pub aiperf_revision: String,
pub aiperf_version: String,
}Fields
repository: Stringrevision: Stringfilename: Stringsha256: Stringcache_path: Option<PathBuf>cache_state: Option<BenchDatasetCacheState>trace_count: u32approximate_bytes: u64license: Stringsource_format: Stringaiperf_loader: Stringmaterialization_identity: Stringscenario: Stringconcurrency_semantics: Stringreplay_semantics: Stringcache_bust: Stringtrajectory_start_min: f64trajectory_start_max: f64global_idle_gap_cap_seconds: f64trace_idle_gap_cap_seconds: f64cache_warmup_requests_per_lane: u64warmup_grace_seconds: u64dataset_configuration_timeout_seconds: u64service_profile_configuration_timeout_seconds: u64default_duration_seconds: u64minimum_duration_seconds: u64failure_threshold: f64dataset_entries: u32streaming: boolignore_eos: booluse_server_token_count: boolgpu_telemetry: boolserver_metric_slice_seconds: u64required_artifacts: Vec<String>inferencex_repository: Stringinferencex_revision: Stringinferencex_reference: Stringaiperf_revision: Stringaiperf_version: StringTrait Implementations
Sourceimpl Clone for BenchAgenticCatalogInput
impl Clone for BenchAgenticCatalogInput
Sourcefn clone(&self) -> BenchAgenticCatalogInput
fn clone(&self) -> BenchAgenticCatalogInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchAgenticCatalogInput
impl Debug for BenchAgenticCatalogInput
Sourceimpl<'de> Deserialize<'de> for BenchAgenticCatalogInput
impl<'de> Deserialize<'de> for BenchAgenticCatalogInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchAgenticCatalogInput
impl JsonSchema for BenchAgenticCatalogInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchAgenticCatalogInput
impl PartialEq for BenchAgenticCatalogInput
Sourceimpl Serialize for BenchAgenticCatalogInput
impl Serialize for BenchAgenticCatalogInput
impl StructuralPartialEq for BenchAgenticCatalogInput