pub struct BenchAgenticResultEvidence {
pub source: BenchAgenticSourceVerification,
pub run: Option<Box<BenchAgenticRunEvidence>>,
}Fields
source: BenchAgenticSourceVerificationrun: Option<Box<BenchAgenticRunEvidence>>Trait Implementations
Sourceimpl Clone for BenchAgenticResultEvidence
impl Clone for BenchAgenticResultEvidence
Sourcefn clone(&self) -> BenchAgenticResultEvidence
fn clone(&self) -> BenchAgenticResultEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchAgenticResultEvidence
impl Debug for BenchAgenticResultEvidence
Sourceimpl<'de> Deserialize<'de> for BenchAgenticResultEvidence
impl<'de> Deserialize<'de> for BenchAgenticResultEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchAgenticResultEvidence
Sourceimpl JsonSchema for BenchAgenticResultEvidence
impl JsonSchema for BenchAgenticResultEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchAgenticResultEvidence