pub struct BenchAgenticSourceInput {
pub dataset: String,
pub profile: String,
pub catalog: Box<BenchAgenticCatalogInput>,
}Expand description
One release-qualified agentic trace source and its complete effective policy.
Fields
dataset: Stringprofile: Stringcatalog: Box<BenchAgenticCatalogInput>Trait Implementations
Sourceimpl Clone for BenchAgenticSourceInput
impl Clone for BenchAgenticSourceInput
Sourcefn clone(&self) -> BenchAgenticSourceInput
fn clone(&self) -> BenchAgenticSourceInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchAgenticSourceInput
impl Debug for BenchAgenticSourceInput
Sourceimpl<'de> Deserialize<'de> for BenchAgenticSourceInput
impl<'de> Deserialize<'de> for BenchAgenticSourceInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchAgenticSourceInput
impl JsonSchema for BenchAgenticSourceInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchAgenticSourceInput
impl PartialEq for BenchAgenticSourceInput
Sourceimpl Serialize for BenchAgenticSourceInput
impl Serialize for BenchAgenticSourceInput
impl StructuralPartialEq for BenchAgenticSourceInput