pub struct BenchAgenticSourceVerification {
pub repository: String,
pub expected_revision: String,
pub observed_revision: Option<String>,
pub filename: String,
pub expected_sha256: String,
pub observed_sha256: Option<String>,
pub cache_path: Option<PathBuf>,
pub cache_state_before: Option<BenchDatasetCacheState>,
pub acquisition_outcome: Option<BenchAgenticAcquisitionOutcome>,
}Fields
repository: Stringexpected_revision: Stringobserved_revision: Option<String>filename: Stringexpected_sha256: Stringobserved_sha256: Option<String>cache_path: Option<PathBuf>cache_state_before: Option<BenchDatasetCacheState>acquisition_outcome: Option<BenchAgenticAcquisitionOutcome>Trait Implementations
Sourceimpl Clone for BenchAgenticSourceVerification
impl Clone for BenchAgenticSourceVerification
Sourcefn clone(&self) -> BenchAgenticSourceVerification
fn clone(&self) -> BenchAgenticSourceVerification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchAgenticSourceVerification
impl<'de> Deserialize<'de> for BenchAgenticSourceVerification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchAgenticSourceVerification
Sourceimpl JsonSchema for BenchAgenticSourceVerification
impl JsonSchema for BenchAgenticSourceVerification
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchAgenticSourceVerification