pub struct BenchCaseInput {
pub load_shape: BenchLoadInput,
pub request_count: u32,
}Expand description
A single Bench case: its load shape and the number of requests to send.
Fields
load_shape: BenchLoadInputrequest_count: u32Trait Implementations
Sourceimpl Clone for BenchCaseInput
impl Clone for BenchCaseInput
Sourcefn clone(&self) -> BenchCaseInput
fn clone(&self) -> BenchCaseInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchCaseInput
impl Debug for BenchCaseInput
Sourceimpl<'de> Deserialize<'de> for BenchCaseInput
impl<'de> Deserialize<'de> for BenchCaseInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchCaseInput
impl JsonSchema for BenchCaseInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchCaseInput
impl PartialEq for BenchCaseInput
Sourceimpl Serialize for BenchCaseInput
impl Serialize for BenchCaseInput
impl StructuralPartialEq for BenchCaseInput