pub struct BenchClientRequest {
pub protocol_version: ProtocolVersion,
pub endpoint: ClientEndpointInput,
pub model: MeasurementModelInput,
pub definition: BenchDefinitionInput,
pub population: Option<BenchPopulationInput>,
pub case: BenchCaseInput,
pub case_budget_seconds: f64,
pub artifact_dir: PathBuf,
}Expand description
The request the Bench measurement runtime passes to its client: the endpoint, model, bench definition, the load case to run, and the artifact directory.
Fields
protocol_version: ProtocolVersionendpoint: ClientEndpointInputmodel: MeasurementModelInputdefinition: BenchDefinitionInputpopulation: Option<BenchPopulationInput>case: BenchCaseInputcase_budget_seconds: f64Remaining control-plane case budget when the client is released.
artifact_dir: PathBufTrait Implementations
Sourceimpl Clone for BenchClientRequest
impl Clone for BenchClientRequest
Sourcefn clone(&self) -> BenchClientRequest
fn clone(&self) -> BenchClientRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchClientRequest
impl Debug for BenchClientRequest
Sourceimpl<'de> Deserialize<'de> for BenchClientRequest
impl<'de> Deserialize<'de> for BenchClientRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchClientRequest
impl JsonSchema for BenchClientRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchClientRequest
impl PartialEq for BenchClientRequest
Sourceimpl Serialize for BenchClientRequest
impl Serialize for BenchClientRequest
impl StructuralPartialEq for BenchClientRequest