pub struct BenchClientResult {
pub schema_version: u32,
pub status: ClientStatus,
pub completed_requests: u64,
pub failed_requests: u64,
pub normalization_schema: String,
pub metrics: BTreeMap<String, f64>,
pub native_command: Vec<String>,
pub native_exit_code: Option<i32>,
pub raw_artifacts: Vec<RawArtifact>,
pub error: Option<String>,
}Expand description
The result a Bench client writes for the measurement runtime to consume.
Fields
schema_version: u32Result envelope version; clients write 1. The measurement runtime
rejects a bench result whose version is not 1.
status: ClientStatuscompleted_requests: u64failed_requests: u64normalization_schema: Stringmetrics: BTreeMap<String, f64>native_command: Vec<String>native_exit_code: Option<i32>raw_artifacts: Vec<RawArtifact>error: Option<String>Trait Implementations
Sourceimpl Clone for BenchClientResult
impl Clone for BenchClientResult
Sourcefn clone(&self) -> BenchClientResult
fn clone(&self) -> BenchClientResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchClientResult
impl Debug for BenchClientResult
Sourceimpl<'de> Deserialize<'de> for BenchClientResult
impl<'de> Deserialize<'de> for BenchClientResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchClientResult
impl JsonSchema for BenchClientResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchClientResult
impl PartialEq for BenchClientResult
Sourcefn eq(&self, other: &BenchClientResult) -> bool
fn eq(&self, other: &BenchClientResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BenchClientResult
impl Serialize for BenchClientResult
impl StructuralPartialEq for BenchClientResult