pub struct BenchDatasetCatalogInput {
pub upstream_identity: String,
pub url: String,
pub sha256: String,
pub source_format: String,
pub license: String,
pub cache_path: PathBuf,
pub cache_state: BenchDatasetCacheState,
pub materialization_identity: String,
}Expand description
Immutable release-catalog facts resolved by the Rust control plane.
Fields
upstream_identity: Stringurl: Stringsha256: Stringsource_format: Stringlicense: Stringcache_path: PathBufcache_state: BenchDatasetCacheStatematerialization_identity: StringTrait Implementations
Sourceimpl Clone for BenchDatasetCatalogInput
impl Clone for BenchDatasetCatalogInput
Sourcefn clone(&self) -> BenchDatasetCatalogInput
fn clone(&self) -> BenchDatasetCatalogInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchDatasetCatalogInput
impl Debug for BenchDatasetCatalogInput
Sourceimpl<'de> Deserialize<'de> for BenchDatasetCatalogInput
impl<'de> Deserialize<'de> for BenchDatasetCatalogInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchDatasetCatalogInput
Sourceimpl JsonSchema for BenchDatasetCatalogInput
impl JsonSchema for BenchDatasetCatalogInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchDatasetCatalogInput
impl PartialEq for BenchDatasetCatalogInput
Sourceimpl Serialize for BenchDatasetCatalogInput
impl Serialize for BenchDatasetCatalogInput
impl StructuralPartialEq for BenchDatasetCatalogInput