pub struct BenchDatasetPreparationRequest {
pub protocol_version: ProtocolVersion,
pub model: MeasurementModelInput,
pub request_source: BenchRequestSourceInput,
pub source_path: PathBuf,
pub required_entries: u32,
pub seed: u64,
pub request_body: BTreeMap<String, SettingValue>,
pub artifact_dir: PathBuf,
}Expand description
The bounded tokenizer-backed operation that materializes one dataset population before any Bench case starts.
Fields
protocol_version: ProtocolVersionmodel: MeasurementModelInputrequest_source: BenchRequestSourceInputsource_path: PathBufrequired_entries: u32seed: u64request_body: BTreeMap<String, SettingValue>artifact_dir: PathBufTrait Implementations
Sourceimpl Clone for BenchDatasetPreparationRequest
impl Clone for BenchDatasetPreparationRequest
Sourcefn clone(&self) -> BenchDatasetPreparationRequest
fn clone(&self) -> BenchDatasetPreparationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchDatasetPreparationRequest
impl<'de> Deserialize<'de> for BenchDatasetPreparationRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchDatasetPreparationRequest
impl JsonSchema for BenchDatasetPreparationRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchDatasetPreparationRequest