pub struct BenchDefinitionInput {
pub request_source: BenchRequestSourceInput,
pub seed: u64,
pub request_body: BTreeMap<String, SettingValue>,
pub request_slo: Option<BenchRequestSloInput>,
pub timeout_seconds: u64,
pub reset_prefix_cache: bool,
}Expand description
The workload shape a Bench client drives, shared across its load cases.
Fields
request_source: BenchRequestSourceInputseed: u64request_body: BTreeMap<String, SettingValue>request_slo: Option<BenchRequestSloInput>timeout_seconds: u64reset_prefix_cache: boolTrait Implementations
Sourceimpl Clone for BenchDefinitionInput
impl Clone for BenchDefinitionInput
Sourcefn clone(&self) -> BenchDefinitionInput
fn clone(&self) -> BenchDefinitionInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchDefinitionInput
impl Debug for BenchDefinitionInput
Sourceimpl<'de> Deserialize<'de> for BenchDefinitionInput
impl<'de> Deserialize<'de> for BenchDefinitionInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchDefinitionInput
impl JsonSchema for BenchDefinitionInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchDefinitionInput
impl PartialEq for BenchDefinitionInput
Sourceimpl Serialize for BenchDefinitionInput
impl Serialize for BenchDefinitionInput
impl StructuralPartialEq for BenchDefinitionInput