pub struct BenchInclusiveUniformInput {
pub kind: BenchTokenDistributionKindInput,
pub min: u32,
pub max: u32,
}Expand description
The one bounded distribution currently supported for a token selector.
Fields
kind: BenchTokenDistributionKindInputmin: u32max: u32Trait Implementations
Sourceimpl Clone for BenchInclusiveUniformInput
impl Clone for BenchInclusiveUniformInput
Sourcefn clone(&self) -> BenchInclusiveUniformInput
fn clone(&self) -> BenchInclusiveUniformInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchInclusiveUniformInput
impl Debug for BenchInclusiveUniformInput
Sourceimpl<'de> Deserialize<'de> for BenchInclusiveUniformInput
impl<'de> Deserialize<'de> for BenchInclusiveUniformInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchInclusiveUniformInput
Sourceimpl JsonSchema for BenchInclusiveUniformInput
impl JsonSchema for BenchInclusiveUniformInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchInclusiveUniformInput