pub struct BenchNativeInvocation {
pub purpose: String,
pub command: Vec<String>,
pub exit_code: Option<i32>,
pub interrupted: bool,
pub timed_out: bool,
}Expand description
One bounded native post-processing command and its terminal outcome.
Fields
purpose: Stringcommand: Vec<String>exit_code: Option<i32>interrupted: booltimed_out: boolTrait Implementations
Sourceimpl Clone for BenchNativeInvocation
impl Clone for BenchNativeInvocation
Sourcefn clone(&self) -> BenchNativeInvocation
fn clone(&self) -> BenchNativeInvocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchNativeInvocation
impl Debug for BenchNativeInvocation
Sourceimpl<'de> Deserialize<'de> for BenchNativeInvocation
impl<'de> Deserialize<'de> for BenchNativeInvocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchNativeInvocation
impl JsonSchema for BenchNativeInvocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchNativeInvocation
impl PartialEq for BenchNativeInvocation
Sourceimpl Serialize for BenchNativeInvocation
impl Serialize for BenchNativeInvocation
impl StructuralPartialEq for BenchNativeInvocation