pub struct BenchPopulationInput {
pub path: PathBuf,
pub sha256: String,
pub entries: u32,
pub tpot_applicable: bool,
}Expand description
One frozen dataset population consumed sequentially by every Bench case.
Fields
path: PathBufsha256: Stringentries: u32tpot_applicable: boolTrait Implementations
Sourceimpl Clone for BenchPopulationInput
impl Clone for BenchPopulationInput
Sourcefn clone(&self) -> BenchPopulationInput
fn clone(&self) -> BenchPopulationInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchPopulationInput
impl Debug for BenchPopulationInput
Sourceimpl<'de> Deserialize<'de> for BenchPopulationInput
impl<'de> Deserialize<'de> for BenchPopulationInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchPopulationInput
Sourceimpl JsonSchema for BenchPopulationInput
impl JsonSchema for BenchPopulationInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchPopulationInput
impl PartialEq for BenchPopulationInput
Sourceimpl Serialize for BenchPopulationInput
impl Serialize for BenchPopulationInput
impl StructuralPartialEq for BenchPopulationInput