pub struct BenchPopulationPreparationResult {Show 14 fields
pub schema_version: u32,
pub status: ClientStatus,
pub materialization_identity: String,
pub requested_entries: u32,
pub candidate_entries: u64,
pub admitted_entries: u64,
pub ineligible_entries: u64,
pub ineligible_reasons: BTreeMap<String, u64>,
pub population: Option<BenchPopulationInput>,
pub input_tokens: Option<BenchTokenCountSummary>,
pub output_tokens: Option<BenchTokenCountSummary>,
pub prompt_token_targeting: Option<BenchPromptTokenTargetingSummary>,
pub evidence_path: Option<PathBuf>,
pub error: Option<String>,
}Expand description
Terminal result of request-population materialization.
Fields
schema_version: u32status: ClientStatusmaterialization_identity: Stringrequested_entries: u32candidate_entries: u64admitted_entries: u64ineligible_entries: u64ineligible_reasons: BTreeMap<String, u64>population: Option<BenchPopulationInput>input_tokens: Option<BenchTokenCountSummary>output_tokens: Option<BenchTokenCountSummary>prompt_token_targeting: Option<BenchPromptTokenTargetingSummary>evidence_path: Option<PathBuf>error: Option<String>Trait Implementations
Sourceimpl Clone for BenchPopulationPreparationResult
impl Clone for BenchPopulationPreparationResult
Sourcefn clone(&self) -> BenchPopulationPreparationResult
fn clone(&self) -> BenchPopulationPreparationResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchPopulationPreparationResult
impl<'de> Deserialize<'de> for BenchPopulationPreparationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchPopulationPreparationResult
impl JsonSchema for BenchPopulationPreparationResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchPopulationPreparationResult