pub struct BenchPrefixConditioningInput {
pub path: PathBuf,
pub sha256: String,
pub prompt_tokens: u32,
}Expand description
File-bound exact canonical prefix used to condition a primed cache start.
Fields
path: PathBufsha256: Stringprompt_tokens: u32Trait Implementations
Sourceimpl Clone for BenchPrefixConditioningInput
impl Clone for BenchPrefixConditioningInput
Sourcefn clone(&self) -> BenchPrefixConditioningInput
fn clone(&self) -> BenchPrefixConditioningInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchPrefixConditioningInput
impl Debug for BenchPrefixConditioningInput
Sourceimpl<'de> Deserialize<'de> for BenchPrefixConditioningInput
impl<'de> Deserialize<'de> for BenchPrefixConditioningInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchPrefixConditioningInput
Sourceimpl JsonSchema for BenchPrefixConditioningInput
impl JsonSchema for BenchPrefixConditioningInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchPrefixConditioningInput