pub struct BenchPrefixGeometrySummary {
pub shared_prefix_tokens: BenchTokenCountSummary,
pub unique_suffix_tokens: BenchTokenCountSummary,
pub maximum_shared_prefix_tokens: u32,
pub canonical_prefix_sha256: String,
pub full_prompt_entries: u32,
}Expand description
Resolved exact final-prompt prefix geometry across one frozen population.
Fields
unique_suffix_tokens: BenchTokenCountSummarycanonical_prefix_sha256: Stringfull_prompt_entries: u32Trait Implementations
Sourceimpl Clone for BenchPrefixGeometrySummary
impl Clone for BenchPrefixGeometrySummary
Sourceimpl Debug for BenchPrefixGeometrySummary
impl Debug for BenchPrefixGeometrySummary
Sourceimpl<'de> Deserialize<'de> for BenchPrefixGeometrySummary
impl<'de> Deserialize<'de> for BenchPrefixGeometrySummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchPrefixGeometrySummary
impl JsonSchema for BenchPrefixGeometrySummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchPrefixGeometrySummary