pub struct BenchPrefixSharingInput {
pub shared_prefix_ratio: f64,
pub shared_prefix_tokens: u32,
pub unique_suffix_tokens: u32,
}Expand description
The effective split between one shared system-message prefix and each request’s independently generated user suffix.
Fields
unique_suffix_tokens: u32Trait Implementations
Sourceimpl Clone for BenchPrefixSharingInput
impl Clone for BenchPrefixSharingInput
Sourcefn clone(&self) -> BenchPrefixSharingInput
fn clone(&self) -> BenchPrefixSharingInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchPrefixSharingInput
impl Debug for BenchPrefixSharingInput
Sourceimpl<'de> Deserialize<'de> for BenchPrefixSharingInput
impl<'de> Deserialize<'de> for BenchPrefixSharingInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchPrefixSharingInput
impl JsonSchema for BenchPrefixSharingInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchPrefixSharingInput
impl PartialEq for BenchPrefixSharingInput
Sourceimpl Serialize for BenchPrefixSharingInput
impl Serialize for BenchPrefixSharingInput
impl StructuralPartialEq for BenchPrefixSharingInput