pub struct BenchPromptCacheObservation {
pub request_id: u64,
pub prompt_tokens: u64,
pub cache_read_tokens: u64,
pub uncached_prompt_tokens: u64,
pub cache_read_ratio: f64,
}Expand description
Backend-reported prompt/cache token accounting for one completed profiling request.
Fields
request_id: u64prompt_tokens: u64cache_read_tokens: u64uncached_prompt_tokens: u64cache_read_ratio: f64Trait Implementations
Sourceimpl Clone for BenchPromptCacheObservation
impl Clone for BenchPromptCacheObservation
Sourceimpl Debug for BenchPromptCacheObservation
impl Debug for BenchPromptCacheObservation
Sourceimpl<'de> Deserialize<'de> for BenchPromptCacheObservation
impl<'de> Deserialize<'de> for BenchPromptCacheObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchPromptCacheObservation
impl JsonSchema for BenchPromptCacheObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchPromptCacheObservation