pub struct BenchPromptTokenReconciliation {
pub population_index: u32,
pub native_session_num: u64,
pub planned_prompt_tokens: u32,
pub observed_prompt_tokens: Option<u32>,
pub reconciled: bool,
}Expand description
One synthetic profiling request’s planned-to-observed prompt-token check.
Fields
population_index: u32native_session_num: u64planned_prompt_tokens: u32observed_prompt_tokens: Option<u32>reconciled: boolTrait Implementations
Sourceimpl Clone for BenchPromptTokenReconciliation
impl Clone for BenchPromptTokenReconciliation
Sourcefn clone(&self) -> BenchPromptTokenReconciliation
fn clone(&self) -> BenchPromptTokenReconciliation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchPromptTokenReconciliation
impl<'de> Deserialize<'de> for BenchPromptTokenReconciliation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchPromptTokenReconciliation
impl JsonSchema for BenchPromptTokenReconciliation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchPromptTokenReconciliation