pub struct BenchPromptTokenTargetingSummary {
pub selected_prompt_tokens: BenchTokenCountSummary,
pub pre_template_content_tokens: BenchTokenCountSummary,
pub projection_template: Option<BenchPromptTemplateProjection>,
pub exact_entries: u32,
pub fallback_entries: u32,
pub fallback_reasons: BTreeMap<String, u32>,
}Expand description
Summary of best-effort complete-prompt targeting for a synthetic population.
Fields
selected_prompt_tokens: BenchTokenCountSummarypre_template_content_tokens: BenchTokenCountSummaryprojection_template: Option<BenchPromptTemplateProjection>exact_entries: u32fallback_entries: u32fallback_reasons: BTreeMap<String, u32>Trait Implementations
Sourceimpl Clone for BenchPromptTokenTargetingSummary
impl Clone for BenchPromptTokenTargetingSummary
Sourcefn clone(&self) -> BenchPromptTokenTargetingSummary
fn clone(&self) -> BenchPromptTokenTargetingSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchPromptTokenTargetingSummary
impl<'de> Deserialize<'de> for BenchPromptTokenTargetingSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchPromptTokenTargetingSummary
impl JsonSchema for BenchPromptTokenTargetingSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchPromptTokenTargetingSummary