pub struct BenchRandomShapeInput {
pub input_tokens: u32,
pub output_tokens: u32,
pub weight: u32,
}Expand description
One exact ISL/OSL pair and its relative categorical sampling weight.
Fields
input_tokens: u32output_tokens: u32weight: u32Trait Implementations
Sourceimpl Clone for BenchRandomShapeInput
impl Clone for BenchRandomShapeInput
Sourcefn clone(&self) -> BenchRandomShapeInput
fn clone(&self) -> BenchRandomShapeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchRandomShapeInput
impl Debug for BenchRandomShapeInput
Sourceimpl<'de> Deserialize<'de> for BenchRandomShapeInput
impl<'de> Deserialize<'de> for BenchRandomShapeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchRandomShapeInput
Sourceimpl JsonSchema for BenchRandomShapeInput
impl JsonSchema for BenchRandomShapeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchRandomShapeInput
impl PartialEq for BenchRandomShapeInput
Sourceimpl Serialize for BenchRandomShapeInput
impl Serialize for BenchRandomShapeInput
impl StructuralPartialEq for BenchRandomShapeInput