pub struct BenchRequestSloInput {
pub request_latency_ms: Option<f64>,
pub ttft_ms: Option<f64>,
pub tpot_ms: Option<f64>,
pub minimum_good_request_ratio: f64,
}Expand description
Per-request latency bounds lowered to the release-owned Bench runner.
Fields
request_latency_ms: Option<f64>ttft_ms: Option<f64>tpot_ms: Option<f64>minimum_good_request_ratio: f64Trait Implementations
Sourceimpl Clone for BenchRequestSloInput
impl Clone for BenchRequestSloInput
Sourcefn clone(&self) -> BenchRequestSloInput
fn clone(&self) -> BenchRequestSloInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchRequestSloInput
impl Debug for BenchRequestSloInput
Sourceimpl<'de> Deserialize<'de> for BenchRequestSloInput
impl<'de> Deserialize<'de> for BenchRequestSloInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchRequestSloInput
impl JsonSchema for BenchRequestSloInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchRequestSloInput
impl PartialEq for BenchRequestSloInput
Sourceimpl Serialize for BenchRequestSloInput
impl Serialize for BenchRequestSloInput
impl StructuralPartialEq for BenchRequestSloInput