pub struct BenchRuntimeSessionResult {
pub phase: String,
pub runtime_session_id: String,
pub template_identity: String,
pub planned_turns: u32,
pub attempted_turns: u32,
pub status: ClientStatus,
pub failure_classification: Option<String>,
pub diagnostic: Option<String>,
pub failing_turn: Option<u32>,
pub suppressed_later_turns: u32,
}Expand description
Terminal evidence for one admitted runtime session.
Fields
phase: Stringruntime_session_id: Stringtemplate_identity: Stringplanned_turns: u32attempted_turns: u32status: ClientStatusfailure_classification: Option<String>diagnostic: Option<String>failing_turn: Option<u32>suppressed_later_turns: u32Trait Implementations
Sourceimpl Clone for BenchRuntimeSessionResult
impl Clone for BenchRuntimeSessionResult
Sourcefn clone(&self) -> BenchRuntimeSessionResult
fn clone(&self) -> BenchRuntimeSessionResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchRuntimeSessionResult
impl Debug for BenchRuntimeSessionResult
Sourceimpl<'de> Deserialize<'de> for BenchRuntimeSessionResult
impl<'de> Deserialize<'de> for BenchRuntimeSessionResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchRuntimeSessionResult
impl JsonSchema for BenchRuntimeSessionResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchRuntimeSessionResult