pub struct BenchSessionDatasetCatalogInput {Show 15 fields
pub dataset: String,
pub profile: Option<String>,
pub source: String,
pub upstream_identity: String,
pub url: String,
pub sha256: String,
pub source_format: String,
pub configuration: Option<String>,
pub split: Option<String>,
pub filter: Option<BenchDatasetFilterInput>,
pub license: String,
pub cache_path: PathBuf,
pub cache_state: BenchDatasetCacheState,
pub materialization_identity: String,
pub provides_output_targets: bool,
}Expand description
Immutable release-catalog facts for a linear-session materializer. AIPerf loader names are deliberately absent from this source boundary.
Fields
dataset: Stringprofile: Option<String>source: Stringupstream_identity: Stringurl: Stringsha256: Stringsource_format: Stringconfiguration: Option<String>split: Option<String>filter: Option<BenchDatasetFilterInput>license: Stringcache_path: PathBufcache_state: BenchDatasetCacheStatematerialization_identity: Stringprovides_output_targets: boolTrait Implementations
Sourceimpl Clone for BenchSessionDatasetCatalogInput
impl Clone for BenchSessionDatasetCatalogInput
Sourcefn clone(&self) -> BenchSessionDatasetCatalogInput
fn clone(&self) -> BenchSessionDatasetCatalogInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchSessionDatasetCatalogInput
impl<'de> Deserialize<'de> for BenchSessionDatasetCatalogInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchSessionDatasetCatalogInput
Sourceimpl JsonSchema for BenchSessionDatasetCatalogInput
impl JsonSchema for BenchSessionDatasetCatalogInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchSessionDatasetCatalogInput