pub struct BenchSessionPhaseSummary {
pub planned_sessions: u32,
pub started_sessions: u32,
pub succeeded_sessions: u32,
pub failed_sessions: u32,
pub planned_requests: u32,
pub attempted_requests: u32,
pub completed_requests: u32,
pub failed_requests: u32,
pub reconciled: bool,
}Expand description
Reconciled native evidence for one session-bounded Bench phase.
Fields
planned_sessions: u32started_sessions: u32succeeded_sessions: u32failed_sessions: u32planned_requests: u32attempted_requests: u32completed_requests: u32failed_requests: u32reconciled: boolTrait Implementations
Sourceimpl Clone for BenchSessionPhaseSummary
impl Clone for BenchSessionPhaseSummary
Sourcefn clone(&self) -> BenchSessionPhaseSummary
fn clone(&self) -> BenchSessionPhaseSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchSessionPhaseSummary
impl Debug for BenchSessionPhaseSummary
Sourceimpl<'de> Deserialize<'de> for BenchSessionPhaseSummary
impl<'de> Deserialize<'de> for BenchSessionPhaseSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchSessionPhaseSummary
impl JsonSchema for BenchSessionPhaseSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchSessionPhaseSummary
impl PartialEq for BenchSessionPhaseSummary
Sourceimpl Serialize for BenchSessionPhaseSummary
impl Serialize for BenchSessionPhaseSummary
impl StructuralPartialEq for BenchSessionPhaseSummary