pub struct BenchSessionResultEvidence {
pub warmup: BenchSessionPhaseSummary,
pub profiling: BenchSessionPhaseSummary,
pub sessions: Vec<BenchRuntimeSessionResult>,
pub turns: Vec<BenchSessionTurnResult>,
pub population_slice_reconciled: bool,
pub sessions_reconciled: bool,
pub turn_order_reconciled: bool,
pub inter_turn_delays_reconciled: bool,
pub native_requests_reconciled: bool,
pub counts_reconciled: bool,
}Expand description
Session and transport reconciliation returned by the Bench client.
Fields
warmup: BenchSessionPhaseSummaryprofiling: BenchSessionPhaseSummarysessions: Vec<BenchRuntimeSessionResult>turns: Vec<BenchSessionTurnResult>population_slice_reconciled: boolsessions_reconciled: boolturn_order_reconciled: boolinter_turn_delays_reconciled: boolnative_requests_reconciled: boolcounts_reconciled: boolTrait Implementations
Sourceimpl Clone for BenchSessionResultEvidence
impl Clone for BenchSessionResultEvidence
Sourcefn clone(&self) -> BenchSessionResultEvidence
fn clone(&self) -> BenchSessionResultEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchSessionResultEvidence
impl Debug for BenchSessionResultEvidence
Sourceimpl<'de> Deserialize<'de> for BenchSessionResultEvidence
impl<'de> Deserialize<'de> for BenchSessionResultEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchSessionResultEvidence
impl JsonSchema for BenchSessionResultEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchSessionResultEvidence