pub struct BenchSessionSourceInput {
pub dataset: String,
pub profile: Option<String>,
pub max_input_tokens: u32,
pub output_tokens: Option<u32>,
pub inter_turn_delay_scale: f64,
pub max_inter_turn_delay_seconds: Option<f64>,
pub catalog: Box<BenchSessionDatasetCatalogInput>,
}Expand description
One release-qualified population of dependent linear session templates.
Fields
dataset: Stringprofile: Option<String>max_input_tokens: u32output_tokens: Option<u32>inter_turn_delay_scale: f64max_inter_turn_delay_seconds: Option<f64>catalog: Box<BenchSessionDatasetCatalogInput>Trait Implementations
Sourceimpl Clone for BenchSessionSourceInput
impl Clone for BenchSessionSourceInput
Sourcefn clone(&self) -> BenchSessionSourceInput
fn clone(&self) -> BenchSessionSourceInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchSessionSourceInput
impl Debug for BenchSessionSourceInput
Sourceimpl<'de> Deserialize<'de> for BenchSessionSourceInput
impl<'de> Deserialize<'de> for BenchSessionSourceInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchSessionSourceInput
impl JsonSchema for BenchSessionSourceInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchSessionSourceInput
impl PartialEq for BenchSessionSourceInput
Sourceimpl Serialize for BenchSessionSourceInput
impl Serialize for BenchSessionSourceInput
impl StructuralPartialEq for BenchSessionSourceInput