pub struct BenchSessionTemplateInput {
pub template_identity: String,
pub turn_count: u32,
}Expand description
One frozen linear-template summary needed to assign case slices without duplicating the content-bearing population evidence artifact.
Fields
template_identity: Stringturn_count: u32Trait Implementations
Sourceimpl Clone for BenchSessionTemplateInput
impl Clone for BenchSessionTemplateInput
Sourcefn clone(&self) -> BenchSessionTemplateInput
fn clone(&self) -> BenchSessionTemplateInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchSessionTemplateInput
impl Debug for BenchSessionTemplateInput
Sourceimpl<'de> Deserialize<'de> for BenchSessionTemplateInput
impl<'de> Deserialize<'de> for BenchSessionTemplateInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BenchSessionTemplateInput
Sourceimpl JsonSchema for BenchSessionTemplateInput
impl JsonSchema for BenchSessionTemplateInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for BenchSessionTemplateInput