pub struct BenchSessionTurnResult {Show 13 fields
pub phase: String,
pub runtime_session_id: String,
pub turn_index: u32,
pub pre_template_content_tokens: u32,
pub observed_prompt_tokens: Option<u32>,
pub native_session_num: u64,
pub preceding_native_session_num: Option<u64>,
pub preceding_terminal_response_receipt_ns: Option<u64>,
pub effective_inter_turn_delay_seconds: Option<f64>,
pub request_start_ns: u64,
pub inter_turn_delay_reconciled: Option<bool>,
pub post_failure_continuation: bool,
pub native_artifact_name: String,
}Expand description
One native transport request reconciled to a linear-session turn.
Fields
phase: Stringruntime_session_id: Stringturn_index: u32pre_template_content_tokens: u32observed_prompt_tokens: Option<u32>native_session_num: u64preceding_native_session_num: Option<u64>preceding_terminal_response_receipt_ns: Option<u64>effective_inter_turn_delay_seconds: Option<f64>request_start_ns: u64inter_turn_delay_reconciled: Option<bool>post_failure_continuation: boolnative_artifact_name: StringTrait Implementations
Sourceimpl Clone for BenchSessionTurnResult
impl Clone for BenchSessionTurnResult
Sourcefn clone(&self) -> BenchSessionTurnResult
fn clone(&self) -> BenchSessionTurnResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchSessionTurnResult
impl Debug for BenchSessionTurnResult
Sourceimpl<'de> Deserialize<'de> for BenchSessionTurnResult
impl<'de> Deserialize<'de> for BenchSessionTurnResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchSessionTurnResult
impl JsonSchema for BenchSessionTurnResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchSessionTurnResult
impl PartialEq for BenchSessionTurnResult
Sourceimpl Serialize for BenchSessionTurnResult
impl Serialize for BenchSessionTurnResult
impl StructuralPartialEq for BenchSessionTurnResult