pub struct BenchTokenCountSummary {
pub minimum: u32,
pub maximum: u32,
pub mean: f64,
}Expand description
Summary of the realized token counts. Exact per-entry values remain in the population evidence artifact.
Fields
minimum: u32maximum: u32mean: f64Trait Implementations
Sourceimpl Clone for BenchTokenCountSummary
impl Clone for BenchTokenCountSummary
Sourcefn clone(&self) -> BenchTokenCountSummary
fn clone(&self) -> BenchTokenCountSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BenchTokenCountSummary
impl Debug for BenchTokenCountSummary
Sourceimpl<'de> Deserialize<'de> for BenchTokenCountSummary
impl<'de> Deserialize<'de> for BenchTokenCountSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BenchTokenCountSummary
impl JsonSchema for BenchTokenCountSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BenchTokenCountSummary
impl PartialEq for BenchTokenCountSummary
Sourceimpl Serialize for BenchTokenCountSummary
impl Serialize for BenchTokenCountSummary
impl StructuralPartialEq for BenchTokenCountSummary