pub struct CaptureWindowControlRequirement {
pub endpoint: CaptureWindowControlEndpoint,
pub start: HttpActionSpec,
pub stop: HttpActionSpec,
}Expand description
The logical workload endpoint and typed actions that open and close a capture window.
Fields
endpoint: CaptureWindowControlEndpointstart: HttpActionSpecstop: HttpActionSpecTrait Implementations
Sourceimpl Clone for CaptureWindowControlRequirement
impl Clone for CaptureWindowControlRequirement
Sourcefn clone(&self) -> CaptureWindowControlRequirement
fn clone(&self) -> CaptureWindowControlRequirement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CaptureWindowControlRequirement
impl<'de> Deserialize<'de> for CaptureWindowControlRequirement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CaptureWindowControlRequirement
Sourceimpl JsonSchema for CaptureWindowControlRequirement
impl JsonSchema for CaptureWindowControlRequirement
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CaptureWindowControlRequirement