pub struct CaptureWindowHttpActionSpec {
pub method: HttpMethod,
pub path: String,
pub body: Option<BTreeMap<String, SettingValue>>,
}Expand description
A capture-window HTTP action invoked against a logical serving endpoint. The integration owns any framework-specific JSON body; the control plane owns execution and evidence.
Fields
method: HttpMethodpath: Stringbody: Option<BTreeMap<String, SettingValue>>Trait Implementations
Sourceimpl Clone for CaptureWindowHttpActionSpec
impl Clone for CaptureWindowHttpActionSpec
Sourcefn clone(&self) -> CaptureWindowHttpActionSpec
fn clone(&self) -> CaptureWindowHttpActionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaptureWindowHttpActionSpec
impl Debug for CaptureWindowHttpActionSpec
Sourceimpl<'de> Deserialize<'de> for CaptureWindowHttpActionSpec
impl<'de> Deserialize<'de> for CaptureWindowHttpActionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CaptureWindowHttpActionSpec
impl JsonSchema for CaptureWindowHttpActionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CaptureWindowHttpActionSpec