pub struct ClientEndpointInput {
pub protocol: EndpointProtocol,
pub host: String,
pub port: u16,
pub completions_path: String,
pub chat_completions_path: String,
}Expand description
The public workload endpoint an Eval or Bench client connects to.
Fields
protocol: EndpointProtocolhost: Stringport: u16completions_path: Stringchat_completions_path: StringTrait Implementations
Sourceimpl Clone for ClientEndpointInput
impl Clone for ClientEndpointInput
Sourcefn clone(&self) -> ClientEndpointInput
fn clone(&self) -> ClientEndpointInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientEndpointInput
impl Debug for ClientEndpointInput
Sourceimpl<'de> Deserialize<'de> for ClientEndpointInput
impl<'de> Deserialize<'de> for ClientEndpointInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ClientEndpointInput
Sourceimpl JsonSchema for ClientEndpointInput
impl JsonSchema for ClientEndpointInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClientEndpointInput
impl PartialEq for ClientEndpointInput
Sourceimpl Serialize for ClientEndpointInput
impl Serialize for ClientEndpointInput
impl StructuralPartialEq for ClientEndpointInput