pub struct EndpointAssignment {
pub host: String,
pub port: u16,
}Expand description
A concrete host/port endpoint the control plane allocated for a process.
Fields
host: Stringport: u16Trait Implementations
Sourceimpl Clone for EndpointAssignment
impl Clone for EndpointAssignment
Sourcefn clone(&self) -> EndpointAssignment
fn clone(&self) -> EndpointAssignment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointAssignment
impl Debug for EndpointAssignment
Sourceimpl<'de> Deserialize<'de> for EndpointAssignment
impl<'de> Deserialize<'de> for EndpointAssignment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EndpointAssignment
Sourceimpl JsonSchema for EndpointAssignment
impl JsonSchema for EndpointAssignment
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EndpointAssignment
impl PartialEq for EndpointAssignment
Sourcefn eq(&self, other: &EndpointAssignment) -> bool
fn eq(&self, other: &EndpointAssignment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EndpointAssignment
impl Serialize for EndpointAssignment
impl StructuralPartialEq for EndpointAssignment