pub struct EvalMetricGate {
pub metric: EvalNormalizedMetric,
pub threshold: f64,
pub comparison: EvalMetricComparison,
pub conclusion: EvalMetricGateConclusion,
}Expand description
The effective threshold comparison for the configured primary metric.
Fields
metric: EvalNormalizedMetricthreshold: f64comparison: EvalMetricComparisonconclusion: EvalMetricGateConclusionTrait Implementations
Sourceimpl Clone for EvalMetricGate
impl Clone for EvalMetricGate
Sourcefn clone(&self) -> EvalMetricGate
fn clone(&self) -> EvalMetricGate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvalMetricGate
impl Debug for EvalMetricGate
Sourceimpl<'de> Deserialize<'de> for EvalMetricGate
impl<'de> Deserialize<'de> for EvalMetricGate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvalMetricGate
impl JsonSchema for EvalMetricGate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EvalMetricGate
impl PartialEq for EvalMetricGate
Sourceimpl Serialize for EvalMetricGate
impl Serialize for EvalMetricGate
impl StructuralPartialEq for EvalMetricGate