pub struct EvalPreparedSourceBinding {
pub workspace_root: PathBuf,
pub task_path: PathBuf,
}Expand description
The immutable workspace-task snapshot consumed by one Eval client.
Fields
workspace_root: PathBuftask_path: PathBufTrait Implementations
Sourceimpl Clone for EvalPreparedSourceBinding
impl Clone for EvalPreparedSourceBinding
Sourcefn clone(&self) -> EvalPreparedSourceBinding
fn clone(&self) -> EvalPreparedSourceBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvalPreparedSourceBinding
impl Debug for EvalPreparedSourceBinding
Sourceimpl<'de> Deserialize<'de> for EvalPreparedSourceBinding
impl<'de> Deserialize<'de> for EvalPreparedSourceBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EvalPreparedSourceBinding
Sourceimpl JsonSchema for EvalPreparedSourceBinding
impl JsonSchema for EvalPreparedSourceBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for EvalPreparedSourceBinding