pub struct EvalTrialSummary {
pub requested_trials: u32,
pub issued_trials: u32,
pub unissued_trials: u32,
pub completed_trials: u32,
pub request_failure_trials: u32,
pub passed_trials: u32,
pub pass_rate: Option<f64>,
pub per_trial_metric: String,
pub per_trial_filter: Option<String>,
pub higher_is_better: bool,
}Expand description
Reconstructible aggregate counts for fixed outer Eval trials.
Fields
requested_trials: u32issued_trials: u32unissued_trials: u32completed_trials: u32request_failure_trials: u32passed_trials: u32pass_rate: Option<f64>per_trial_metric: Stringper_trial_filter: Option<String>higher_is_better: boolTrait Implementations
Sourceimpl Clone for EvalTrialSummary
impl Clone for EvalTrialSummary
Sourcefn clone(&self) -> EvalTrialSummary
fn clone(&self) -> EvalTrialSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvalTrialSummary
impl Debug for EvalTrialSummary
Sourceimpl<'de> Deserialize<'de> for EvalTrialSummary
impl<'de> Deserialize<'de> for EvalTrialSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvalTrialSummary
impl JsonSchema for EvalTrialSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EvalTrialSummary
impl PartialEq for EvalTrialSummary
Sourceimpl Serialize for EvalTrialSummary
impl Serialize for EvalTrialSummary
impl StructuralPartialEq for EvalTrialSummary