pub struct FrontendCoRendering {
pub process_role: FrontendProcessRole,
}Expand description
The fixed co-rendering requirement shared by compatible frontend plans.
Fields
process_role: FrontendProcessRoleTrait Implementations
Sourceimpl Clone for FrontendCoRendering
impl Clone for FrontendCoRendering
Sourcefn clone(&self) -> FrontendCoRendering
fn clone(&self) -> FrontendCoRendering
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrontendCoRendering
impl Debug for FrontendCoRendering
Sourceimpl<'de> Deserialize<'de> for FrontendCoRendering
impl<'de> Deserialize<'de> for FrontendCoRendering
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FrontendCoRendering
Sourceimpl JsonSchema for FrontendCoRendering
impl JsonSchema for FrontendCoRendering
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FrontendCoRendering
impl PartialEq for FrontendCoRendering
Sourceimpl Serialize for FrontendCoRendering
impl Serialize for FrontendCoRendering
impl StructuralPartialEq for FrontendCoRendering