pub struct GatewayFrontendBinding(pub [FrontendGatewayComponent; 1]);Expand description
The stable schema branch for a Gateway-only frontend binding.
Tuple Fields
0: [FrontendGatewayComponent; 1]Trait Implementations
Sourceimpl Clone for GatewayFrontendBinding
impl Clone for GatewayFrontendBinding
Sourcefn clone(&self) -> GatewayFrontendBinding
fn clone(&self) -> GatewayFrontendBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GatewayFrontendBinding
impl Debug for GatewayFrontendBinding
Sourceimpl<'de> Deserialize<'de> for GatewayFrontendBinding
impl<'de> Deserialize<'de> for GatewayFrontendBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GatewayFrontendBinding
Sourceimpl JsonSchema for GatewayFrontendBinding
impl JsonSchema for GatewayFrontendBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GatewayFrontendBinding
impl PartialEq for GatewayFrontendBinding
Sourceimpl Serialize for GatewayFrontendBinding
impl Serialize for GatewayFrontendBinding
impl StructuralPartialEq for GatewayFrontendBinding