pub struct GatewayPdRouterFrontendBinding(pub (FrontendGatewayComponent, FrontendPdRouterComponent));Expand description
The stable schema branch for a fused Gateway and P/D Router binding.
Tuple Fields
0: (FrontendGatewayComponent, FrontendPdRouterComponent)Trait Implementations
Sourceimpl Clone for GatewayPdRouterFrontendBinding
impl Clone for GatewayPdRouterFrontendBinding
Sourcefn clone(&self) -> GatewayPdRouterFrontendBinding
fn clone(&self) -> GatewayPdRouterFrontendBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GatewayPdRouterFrontendBinding
impl<'de> Deserialize<'de> for GatewayPdRouterFrontendBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GatewayPdRouterFrontendBinding
Sourceimpl JsonSchema for GatewayPdRouterFrontendBinding
impl JsonSchema for GatewayPdRouterFrontendBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for GatewayPdRouterFrontendBinding