pub struct GatewayPlan {
pub backend: String,
pub implementation: String,
pub implementation_version: String,
pub effective_settings: BTreeMap<String, SettingValue>,
pub endpoint: EndpointRequirement,
pub readiness: ReadinessProbe,
pub ports: Vec<String>,
pub targets: Vec<GatewayTarget>,
pub render_inputs: Vec<RenderInputDeclaration>,
pub render_source: RenderSource,
pub co_rendering: FrontendCoRendering,
}Expand description
The public frontend component plan returned independently from Engine and P/D Router planning.
Fields
backend: Stringimplementation: Stringimplementation_version: Stringeffective_settings: BTreeMap<String, SettingValue>endpoint: EndpointRequirementreadiness: ReadinessProbeports: Vec<String>targets: Vec<GatewayTarget>render_inputs: Vec<RenderInputDeclaration>render_source: RenderSourceco_rendering: FrontendCoRenderingTrait Implementations
Sourceimpl Clone for GatewayPlan
impl Clone for GatewayPlan
Sourcefn clone(&self) -> GatewayPlan
fn clone(&self) -> GatewayPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GatewayPlan
impl Debug for GatewayPlan
Sourceimpl<'de> Deserialize<'de> for GatewayPlan
impl<'de> Deserialize<'de> for GatewayPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GatewayPlan
impl JsonSchema for GatewayPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GatewayPlan
impl PartialEq for GatewayPlan
Sourceimpl Serialize for GatewayPlan
impl Serialize for GatewayPlan
impl StructuralPartialEq for GatewayPlan