pub struct HttpActionSpec {
pub method: HttpMethod,
pub path: String,
}Expand description
An HTTP action (method and path) invoked against the workload endpoint.
Fields
method: HttpMethodpath: StringTrait Implementations
Sourceimpl Clone for HttpActionSpec
impl Clone for HttpActionSpec
Sourcefn clone(&self) -> HttpActionSpec
fn clone(&self) -> HttpActionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HttpActionSpec
impl Debug for HttpActionSpec
Sourceimpl<'de> Deserialize<'de> for HttpActionSpec
impl<'de> Deserialize<'de> for HttpActionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HttpActionSpec
Sourceimpl JsonSchema for HttpActionSpec
impl JsonSchema for HttpActionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HttpActionSpec
impl PartialEq for HttpActionSpec
Sourceimpl Serialize for HttpActionSpec
impl Serialize for HttpActionSpec
impl StructuralPartialEq for HttpActionSpec