pub struct HttpTargetRegistryReadiness {
pub target_scheme: TargetEndpointScheme,
pub readiness_path: String,
pub registry_path: String,
pub targets_field: String,
pub target_url_field: String,
pub target_role_field: String,
pub target_healthy_field: String,
pub target_bootstrap_port_field: String,
pub prefill_role_value: String,
pub decode_role_value: String,
pub prefill_bootstrap_port: String,
}Expand description
The integration-owned HTTP registry contract for target-aware readiness.
Fields
target_scheme: TargetEndpointSchemereadiness_path: Stringregistry_path: Stringtargets_field: Stringtarget_url_field: Stringtarget_role_field: Stringtarget_healthy_field: Stringtarget_bootstrap_port_field: Stringprefill_role_value: Stringdecode_role_value: Stringprefill_bootstrap_port: StringTrait Implementations
Sourceimpl Clone for HttpTargetRegistryReadiness
impl Clone for HttpTargetRegistryReadiness
Sourcefn clone(&self) -> HttpTargetRegistryReadiness
fn clone(&self) -> HttpTargetRegistryReadiness
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HttpTargetRegistryReadiness
impl Debug for HttpTargetRegistryReadiness
Sourceimpl<'de> Deserialize<'de> for HttpTargetRegistryReadiness
impl<'de> Deserialize<'de> for HttpTargetRegistryReadiness
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HttpTargetRegistryReadiness
Sourceimpl JsonSchema for HttpTargetRegistryReadiness
impl JsonSchema for HttpTargetRegistryReadiness
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for HttpTargetRegistryReadiness