pub struct IntegrationIdentity {
pub adapter_id: String,
pub adapter_version: String,
pub framework: String,
}Expand description
The integration’s identity recorded on its results: adapter id, adapter version, and the framework it lowers to.
Fields
adapter_id: Stringadapter_version: Stringframework: StringTrait Implementations
Sourceimpl Clone for IntegrationIdentity
impl Clone for IntegrationIdentity
Sourcefn clone(&self) -> IntegrationIdentity
fn clone(&self) -> IntegrationIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntegrationIdentity
impl Debug for IntegrationIdentity
Sourceimpl<'de> Deserialize<'de> for IntegrationIdentity
impl<'de> Deserialize<'de> for IntegrationIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for IntegrationIdentity
Sourceimpl JsonSchema for IntegrationIdentity
impl JsonSchema for IntegrationIdentity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IntegrationIdentity
impl PartialEq for IntegrationIdentity
Sourcefn eq(&self, other: &IntegrationIdentity) -> bool
fn eq(&self, other: &IntegrationIdentity) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IntegrationIdentity
impl Serialize for IntegrationIdentity
impl StructuralPartialEq for IntegrationIdentity