pub struct JsonValueMatch {
pub pointer: String,
pub value: String,
}Expand description
A JSON Pointer and the string value expected at it.
Fields
pointer: Stringvalue: StringTrait Implementations
Sourceimpl Clone for JsonValueMatch
impl Clone for JsonValueMatch
Sourceimpl Debug for JsonValueMatch
impl Debug for JsonValueMatch
Sourceimpl<'de> Deserialize<'de> for JsonValueMatch
impl<'de> Deserialize<'de> for JsonValueMatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for JsonValueMatch
Sourceimpl JsonSchema for JsonValueMatch
impl JsonSchema for JsonValueMatch
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for JsonValueMatch
impl PartialEq for JsonValueMatch
Sourceimpl Serialize for JsonValueMatch
impl Serialize for JsonValueMatch
impl StructuralPartialEq for JsonValueMatch