pub struct LaunchFileDeclaration {
pub relative_path: String,
pub text: String,
pub sha256: String,
}Expand description
One immutable text input a rendered process requires before it can launch.
Fields
relative_path: Stringtext: Stringsha256: StringTrait Implementations
Sourceimpl Clone for LaunchFileDeclaration
impl Clone for LaunchFileDeclaration
Sourcefn clone(&self) -> LaunchFileDeclaration
fn clone(&self) -> LaunchFileDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LaunchFileDeclaration
impl Debug for LaunchFileDeclaration
Sourceimpl<'de> Deserialize<'de> for LaunchFileDeclaration
impl<'de> Deserialize<'de> for LaunchFileDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LaunchFileDeclaration
Sourceimpl JsonSchema for LaunchFileDeclaration
impl JsonSchema for LaunchFileDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LaunchFileDeclaration
impl PartialEq for LaunchFileDeclaration
Sourceimpl Serialize for LaunchFileDeclaration
impl Serialize for LaunchFileDeclaration
impl StructuralPartialEq for LaunchFileDeclaration