pub struct MeasurementDataAssetContentEntry {
pub relative_path: String,
pub sha256: String,
}Expand description
One member of a complete, ordered content closure.
Fields
relative_path: Stringsha256: StringTrait Implementations
Sourceimpl Clone for MeasurementDataAssetContentEntry
impl Clone for MeasurementDataAssetContentEntry
Sourcefn clone(&self) -> MeasurementDataAssetContentEntry
fn clone(&self) -> MeasurementDataAssetContentEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MeasurementDataAssetContentEntry
impl<'de> Deserialize<'de> for MeasurementDataAssetContentEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MeasurementDataAssetContentEntry
Sourceimpl JsonSchema for MeasurementDataAssetContentEntry
impl JsonSchema for MeasurementDataAssetContentEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for MeasurementDataAssetContentEntry