pub struct MeasurementDataAssetVerification {
pub subject: String,
pub expected: String,
pub observed: Option<String>,
pub matched: bool,
}Expand description
Expected-versus-observed integrity evidence for qualified source content.
Fields
subject: Stringexpected: Stringobserved: Option<String>matched: boolTrait Implementations
Sourceimpl Clone for MeasurementDataAssetVerification
impl Clone for MeasurementDataAssetVerification
Sourcefn clone(&self) -> MeasurementDataAssetVerification
fn clone(&self) -> MeasurementDataAssetVerification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MeasurementDataAssetVerification
impl<'de> Deserialize<'de> for MeasurementDataAssetVerification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MeasurementDataAssetVerification
Sourceimpl JsonSchema for MeasurementDataAssetVerification
impl JsonSchema for MeasurementDataAssetVerification
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for MeasurementDataAssetVerification