pub struct MeasurementModelInput {
pub locator: String,
pub served_name: String,
}Expand description
The model identity used by measurement clients. Unlike integration planning, a benchmark client may need a controller-visible tokenizer locator.
Fields
locator: Stringserved_name: StringTrait Implementations
Sourceimpl Clone for MeasurementModelInput
impl Clone for MeasurementModelInput
Sourcefn clone(&self) -> MeasurementModelInput
fn clone(&self) -> MeasurementModelInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeasurementModelInput
impl Debug for MeasurementModelInput
Sourceimpl<'de> Deserialize<'de> for MeasurementModelInput
impl<'de> Deserialize<'de> for MeasurementModelInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MeasurementModelInput
Sourceimpl JsonSchema for MeasurementModelInput
impl JsonSchema for MeasurementModelInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MeasurementModelInput
impl PartialEq for MeasurementModelInput
Sourceimpl Serialize for MeasurementModelInput
impl Serialize for MeasurementModelInput
impl StructuralPartialEq for MeasurementModelInput