pub struct MeasurementProtocol {
pub eval_client_request: Option<EvalClientRequest>,
pub eval_client_result: Option<EvalClientResult>,
pub bench_client_request: Option<BenchClientRequest>,
pub bench_client_result: Option<BenchClientResult>,
pub bench_dataset_preparation_request: Option<BenchDatasetPreparationRequest>,
pub bench_dataset_preparation_result: Option<BenchDatasetPreparationResult>,
}Expand description
The schema root aggregating the request and result surfaces used by the product-owned Eval and Bench measurement clients. Its optional fields are code-generation anchors and are never all populated in one message.
Fields
eval_client_request: Option<EvalClientRequest>eval_client_result: Option<EvalClientResult>bench_client_request: Option<BenchClientRequest>bench_client_result: Option<BenchClientResult>bench_dataset_preparation_request: Option<BenchDatasetPreparationRequest>bench_dataset_preparation_result: Option<BenchDatasetPreparationResult>Trait Implementations
Sourceimpl Clone for MeasurementProtocol
impl Clone for MeasurementProtocol
Sourcefn clone(&self) -> MeasurementProtocol
fn clone(&self) -> MeasurementProtocol
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeasurementProtocol
impl Debug for MeasurementProtocol
Sourceimpl<'de> Deserialize<'de> for MeasurementProtocol
impl<'de> Deserialize<'de> for MeasurementProtocol
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MeasurementProtocol
impl JsonSchema for MeasurementProtocol
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MeasurementProtocol
impl PartialEq for MeasurementProtocol
Sourceimpl Serialize for MeasurementProtocol
impl Serialize for MeasurementProtocol
impl StructuralPartialEq for MeasurementProtocol