pub struct ModelListRequirement {
pub path: String,
pub models_pointer: String,
pub name_pointer: String,
}Expand description
A served-model list that must name the served model.
Fields
path: StringAbsolute HTTP path of the list on the owning process’s endpoint.
models_pointer: StringPointer from the list document to the model array.
name_pointer: StringPointer from one model element to its name.