pub struct ParallelismAttention {
pub tensor_parallel_size: Option<u32>,
pub data_parallel_size: Option<u32>,
pub context_parallel_size: Option<u32>,
}Expand description
Attention-block parallelism: tensor, data, and context degrees.
Fields
tensor_parallel_size: Option<u32>data_parallel_size: Option<u32>context_parallel_size: Option<u32>Trait Implementations
Sourceimpl Clone for ParallelismAttention
impl Clone for ParallelismAttention
Sourcefn clone(&self) -> ParallelismAttention
fn clone(&self) -> ParallelismAttention
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParallelismAttention
impl Debug for ParallelismAttention
Sourceimpl Default for ParallelismAttention
impl Default for ParallelismAttention
Sourcefn default() -> ParallelismAttention
fn default() -> ParallelismAttention
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ParallelismAttentionwhere
ParallelismAttention: Default,
impl<'de> Deserialize<'de> for ParallelismAttentionwhere
ParallelismAttention: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ParallelismAttention
Sourceimpl JsonSchema for ParallelismAttention
impl JsonSchema for ParallelismAttention
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ParallelismAttention
impl PartialEq for ParallelismAttention
Sourcefn eq(&self, other: &ParallelismAttention) -> bool
fn eq(&self, other: &ParallelismAttention) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ParallelismAttention
impl Serialize for ParallelismAttention
impl StructuralPartialEq for ParallelismAttention