pub struct ParallelismExperts {
pub tensor_parallel_size: Option<u32>,
pub data_parallel_size: Option<u32>,
pub expert_parallel_size: Option<u32>,
pub dense_tensor_parallel_size: Option<u32>,
}Expand description
MoE expert parallelism: tensor, data, expert, and dense-tensor degrees.
Fields
tensor_parallel_size: Option<u32>data_parallel_size: Option<u32>expert_parallel_size: Option<u32>dense_tensor_parallel_size: Option<u32>Trait Implementations
Sourceimpl Clone for ParallelismExperts
impl Clone for ParallelismExperts
Sourcefn clone(&self) -> ParallelismExperts
fn clone(&self) -> ParallelismExperts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParallelismExperts
impl Debug for ParallelismExperts
Sourceimpl Default for ParallelismExperts
impl Default for ParallelismExperts
Sourcefn default() -> ParallelismExperts
fn default() -> ParallelismExperts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ParallelismExpertswhere
ParallelismExperts: Default,
impl<'de> Deserialize<'de> for ParallelismExpertswhere
ParallelismExperts: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ParallelismExperts
Sourceimpl JsonSchema for ParallelismExperts
impl JsonSchema for ParallelismExperts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ParallelismExperts
impl PartialEq for ParallelismExperts
Sourceimpl Serialize for ParallelismExperts
impl Serialize for ParallelismExperts
impl StructuralPartialEq for ParallelismExperts