pub struct ParallelismOuter {
pub tensor_parallel_size: Option<u32>,
pub pipeline_parallel_size: Option<u32>,
}Expand description
Outer deployment parallelism: tensor and pipeline degrees.
Fields
tensor_parallel_size: Option<u32>pipeline_parallel_size: Option<u32>Trait Implementations
Sourceimpl Clone for ParallelismOuter
impl Clone for ParallelismOuter
Sourcefn clone(&self) -> ParallelismOuter
fn clone(&self) -> ParallelismOuter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParallelismOuter
impl Debug for ParallelismOuter
Sourceimpl Default for ParallelismOuter
impl Default for ParallelismOuter
Sourcefn default() -> ParallelismOuter
fn default() -> ParallelismOuter
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ParallelismOuterwhere
ParallelismOuter: Default,
impl<'de> Deserialize<'de> for ParallelismOuterwhere
ParallelismOuter: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ParallelismOuter
Sourceimpl JsonSchema for ParallelismOuter
impl JsonSchema for ParallelismOuter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ParallelismOuter
impl PartialEq for ParallelismOuter
Sourcefn eq(&self, other: &ParallelismOuter) -> bool
fn eq(&self, other: &ParallelismOuter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ParallelismOuter
impl Serialize for ParallelismOuter
impl StructuralPartialEq for ParallelismOuter