pub struct PdRouterPlan {Show 14 fields
pub backend: String,
pub implementation: String,
pub implementation_version: String,
pub effective_settings: BTreeMap<String, SettingValue>,
pub policies: PdRoutingPolicies,
pub prefill_role: String,
pub decode_role: String,
pub target_scheme: TargetEndpointScheme,
pub ports: Vec<String>,
pub readiness: ReadinessProbe,
pub handoff: FrontendHandoff,
pub render_inputs: Vec<RenderInputDeclaration>,
pub render_source: RenderSource,
pub co_rendering: FrontendCoRendering,
}Expand description
The P/D orchestration component plan, kept separate even when the same process and provider also realize Gateway.
Fields
backend: Stringimplementation: Stringimplementation_version: Stringeffective_settings: BTreeMap<String, SettingValue>policies: PdRoutingPoliciesprefill_role: Stringdecode_role: Stringtarget_scheme: TargetEndpointSchemeports: Vec<String>readiness: ReadinessProbehandoff: FrontendHandoffrender_inputs: Vec<RenderInputDeclaration>render_source: RenderSourceco_rendering: FrontendCoRenderingTrait Implementations
Sourceimpl Clone for PdRouterPlan
impl Clone for PdRouterPlan
Sourcefn clone(&self) -> PdRouterPlan
fn clone(&self) -> PdRouterPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PdRouterPlan
impl Debug for PdRouterPlan
Sourceimpl<'de> Deserialize<'de> for PdRouterPlan
impl<'de> Deserialize<'de> for PdRouterPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PdRouterPlan
impl JsonSchema for PdRouterPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PdRouterPlan
impl PartialEq for PdRouterPlan
Sourceimpl Serialize for PdRouterPlan
impl Serialize for PdRouterPlan
impl StructuralPartialEq for PdRouterPlan