pub struct PdRoutingPolicies {
pub prefill: String,
pub decode: String,
}Expand description
Independent policies for choosing prefill and decode targets.
Fields
prefill: Stringdecode: StringTrait Implementations
Sourceimpl Clone for PdRoutingPolicies
impl Clone for PdRoutingPolicies
Sourcefn clone(&self) -> PdRoutingPolicies
fn clone(&self) -> PdRoutingPolicies
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PdRoutingPolicies
impl Debug for PdRoutingPolicies
Sourceimpl<'de> Deserialize<'de> for PdRoutingPolicies
impl<'de> Deserialize<'de> for PdRoutingPolicies
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PdRoutingPolicies
Sourceimpl JsonSchema for PdRoutingPolicies
impl JsonSchema for PdRoutingPolicies
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PdRoutingPolicies
impl PartialEq for PdRoutingPolicies
Sourceimpl Serialize for PdRoutingPolicies
impl Serialize for PdRoutingPolicies
impl StructuralPartialEq for PdRoutingPolicies