pub struct PlanServeInput {
pub model: ServeModelInput,
pub topology: ServeTopology,
pub gateway_backend: Option<String>,
pub pd_router_backend: Option<String>,
pub kv_transfer: Option<KvTransferMechanism>,
pub roles: Vec<ServeRoleInput>,
pub profiling: bool,
}Expand description
The requested serve shape a PlanServe operation lowers into a topology.
Fields
model: ServeModelInputtopology: ServeTopologygateway_backend: Option<String>pd_router_backend: Option<String>kv_transfer: Option<KvTransferMechanism>roles: Vec<ServeRoleInput>profiling: boolTrait Implementations
Sourceimpl Clone for PlanServeInput
impl Clone for PlanServeInput
Sourcefn clone(&self) -> PlanServeInput
fn clone(&self) -> PlanServeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanServeInput
impl Debug for PlanServeInput
Sourceimpl<'de> Deserialize<'de> for PlanServeInput
impl<'de> Deserialize<'de> for PlanServeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlanServeInput
impl JsonSchema for PlanServeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlanServeInput
impl PartialEq for PlanServeInput
Sourceimpl Serialize for PlanServeInput
impl Serialize for PlanServeInput
impl StructuralPartialEq for PlanServeInput