pub struct PlanServeResult {
pub integration: IntegrationIdentity,
pub effective_settings: BTreeMap<String, SettingValue>,
pub effective_parallelism: Parallelism,
pub roles: Vec<ServeRoleResult>,
pub replicas: Vec<ServeReplicaRequirement>,
pub links: Vec<ServeRoleLink>,
pub public_endpoint: PublicEndpointRequirement,
pub endpoint: EndpointRequirement,
}Expand description
The lowered topology returned by a PlanServe: the effective server-level
shape, per-role resolution, whole-replica requirements, role links, and the
public and per-role endpoint requirements the control plane then allocates.
Fields
integration: IntegrationIdentityeffective_settings: BTreeMap<String, SettingValue>effective_parallelism: Parallelismroles: Vec<ServeRoleResult>replicas: Vec<ServeReplicaRequirement>links: Vec<ServeRoleLink>public_endpoint: PublicEndpointRequirementendpoint: EndpointRequirementTrait Implementations
Sourceimpl Clone for PlanServeResult
impl Clone for PlanServeResult
Sourcefn clone(&self) -> PlanServeResult
fn clone(&self) -> PlanServeResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanServeResult
impl Debug for PlanServeResult
Sourceimpl<'de> Deserialize<'de> for PlanServeResult
impl<'de> Deserialize<'de> for PlanServeResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlanServeResult
impl JsonSchema for PlanServeResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlanServeResult
impl PartialEq for PlanServeResult
Sourcefn eq(&self, other: &PlanServeResult) -> bool
fn eq(&self, other: &PlanServeResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PlanServeResult
impl Serialize for PlanServeResult
impl StructuralPartialEq for PlanServeResult