pub struct ProcessSpec {
pub argv: Vec<String>,
pub env: BTreeMap<String, String>,
}Expand description
A launchable process: its argument vector and environment.
Fields
argv: Vec<String>env: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for ProcessSpec
impl Clone for ProcessSpec
Sourcefn clone(&self) -> ProcessSpec
fn clone(&self) -> ProcessSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessSpec
impl Debug for ProcessSpec
Sourceimpl<'de> Deserialize<'de> for ProcessSpec
impl<'de> Deserialize<'de> for ProcessSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProcessSpec
Sourceimpl JsonSchema for ProcessSpec
impl JsonSchema for ProcessSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessSpec
impl PartialEq for ProcessSpec
Sourcefn eq(&self, other: &ProcessSpec) -> bool
fn eq(&self, other: &ProcessSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessSpec
impl Serialize for ProcessSpec
impl StructuralPartialEq for ProcessSpec