pub struct RawArtifact {
pub name: String,
pub kind: String,
pub path: PathBuf,
}Expand description
A raw output file a client produced, retained as workload evidence.
Fields
name: Stringkind: Stringpath: PathBufTrait Implementations
Sourceimpl Clone for RawArtifact
impl Clone for RawArtifact
Sourcefn clone(&self) -> RawArtifact
fn clone(&self) -> RawArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawArtifact
impl Debug for RawArtifact
Sourceimpl<'de> Deserialize<'de> for RawArtifact
impl<'de> Deserialize<'de> for RawArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RawArtifact
Sourceimpl JsonSchema for RawArtifact
impl JsonSchema for RawArtifact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RawArtifact
impl PartialEq for RawArtifact
Sourceimpl Serialize for RawArtifact
impl Serialize for RawArtifact
impl StructuralPartialEq for RawArtifact