pub struct RegistryRoleValues {
pub serve: Option<String>,
pub prefill: Option<String>,
pub decode: Option<String>,
}Expand description
The registry role value expected for each model-serving role kind present in the topology.
Fields
serve: Option<String>prefill: Option<String>decode: Option<String>Trait Implementations
Sourceimpl Clone for RegistryRoleValues
impl Clone for RegistryRoleValues
Sourceimpl Debug for RegistryRoleValues
impl Debug for RegistryRoleValues
Sourceimpl Default for RegistryRoleValues
impl Default for RegistryRoleValues
Sourceimpl<'de> Deserialize<'de> for RegistryRoleValues
impl<'de> Deserialize<'de> for RegistryRoleValues
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RegistryRoleValues
Sourceimpl JsonSchema for RegistryRoleValues
impl JsonSchema for RegistryRoleValues
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RegistryRoleValues
impl PartialEq for RegistryRoleValues
Sourceimpl Serialize for RegistryRoleValues
impl Serialize for RegistryRoleValues
impl StructuralPartialEq for RegistryRoleValues