pub struct RenderInputDeclaration {
pub source_path: String,
}Expand description
One workspace-authored UTF-8 source file an integration declares during planning for the control plane to supply during final rendering.
Fields
source_path: StringTrait Implementations
Sourceimpl Clone for RenderInputDeclaration
impl Clone for RenderInputDeclaration
Sourcefn clone(&self) -> RenderInputDeclaration
fn clone(&self) -> RenderInputDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderInputDeclaration
impl Debug for RenderInputDeclaration
Sourceimpl<'de> Deserialize<'de> for RenderInputDeclaration
impl<'de> Deserialize<'de> for RenderInputDeclaration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RenderInputDeclaration
Sourceimpl JsonSchema for RenderInputDeclaration
impl JsonSchema for RenderInputDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RenderInputDeclaration
impl PartialEq for RenderInputDeclaration
Sourceimpl Serialize for RenderInputDeclaration
impl Serialize for RenderInputDeclaration
impl StructuralPartialEq for RenderInputDeclaration