pub struct RenderServeInput {
pub model: ServeModelInput,
pub topology: ServeTopology,
pub routing_backend: Option<String>,
pub kv_transfer: Option<KvTransferMechanism>,
pub roles: Vec<ServeRoleResult>,
pub routing: RoutingResult,
pub links: Vec<ServeRoleLink>,
pub allocations: Vec<ServeProcessAllocation>,
pub render_inputs: Vec<SuppliedRenderInput>,
pub profiling: bool,
}Expand description
The planned topology plus the control plane’s concrete allocations that a
RenderServe operation turns into final process invocations.
Fields
model: ServeModelInputtopology: ServeTopologyrouting_backend: Option<String>kv_transfer: Option<KvTransferMechanism>roles: Vec<ServeRoleResult>routing: RoutingResultlinks: Vec<ServeRoleLink>allocations: Vec<ServeProcessAllocation>render_inputs: Vec<SuppliedRenderInput>profiling: boolTrait Implementations
Sourceimpl Clone for RenderServeInput
impl Clone for RenderServeInput
Sourcefn clone(&self) -> RenderServeInput
fn clone(&self) -> RenderServeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderServeInput
impl Debug for RenderServeInput
Sourceimpl<'de> Deserialize<'de> for RenderServeInput
impl<'de> Deserialize<'de> for RenderServeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RenderServeInput
impl JsonSchema for RenderServeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RenderServeInput
impl PartialEq for RenderServeInput
Sourceimpl Serialize for RenderServeInput
impl Serialize for RenderServeInput
impl StructuralPartialEq for RenderServeInput