pub struct RenderServeResult {
pub integration: IntegrationIdentity,
pub processes: Vec<RenderedServeProcess>,
}Expand description
The final process invocations returned by a RenderServe, one per supplied
allocation.
Fields
integration: IntegrationIdentityprocesses: Vec<RenderedServeProcess>Trait Implementations
Sourceimpl Clone for RenderServeResult
impl Clone for RenderServeResult
Sourcefn clone(&self) -> RenderServeResult
fn clone(&self) -> RenderServeResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderServeResult
impl Debug for RenderServeResult
Sourceimpl<'de> Deserialize<'de> for RenderServeResult
impl<'de> Deserialize<'de> for RenderServeResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RenderServeResult
Sourceimpl JsonSchema for RenderServeResult
impl JsonSchema for RenderServeResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RenderServeResult
impl PartialEq for RenderServeResult
Sourceimpl Serialize for RenderServeResult
impl Serialize for RenderServeResult
impl StructuralPartialEq for RenderServeResult