pub struct RenderedServeProcess {
pub id: String,
pub launch_files: Vec<LaunchFileDeclaration>,
pub process: ProcessSpec,
}Expand description
A rendered process bound to the allocation id it was produced for.
Fields
id: Stringlaunch_files: Vec<LaunchFileDeclaration>process: ProcessSpecTrait Implementations
Sourceimpl Clone for RenderedServeProcess
impl Clone for RenderedServeProcess
Sourcefn clone(&self) -> RenderedServeProcess
fn clone(&self) -> RenderedServeProcess
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderedServeProcess
impl Debug for RenderedServeProcess
Sourceimpl<'de> Deserialize<'de> for RenderedServeProcess
impl<'de> Deserialize<'de> for RenderedServeProcess
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RenderedServeProcess
Sourceimpl JsonSchema for RenderedServeProcess
impl JsonSchema for RenderedServeProcess
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RenderedServeProcess
impl PartialEq for RenderedServeProcess
Sourceimpl Serialize for RenderedServeProcess
impl Serialize for RenderedServeProcess
impl StructuralPartialEq for RenderedServeProcess