pub struct ServeModelInput {
pub id: String,
pub served_name: String,
}Expand description
The logical model supplied during serving planning and rendering.
Fields
id: Stringserved_name: StringTrait Implementations
Sourceimpl Clone for ServeModelInput
impl Clone for ServeModelInput
Sourcefn clone(&self) -> ServeModelInput
fn clone(&self) -> ServeModelInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServeModelInput
impl Debug for ServeModelInput
Sourceimpl<'de> Deserialize<'de> for ServeModelInput
impl<'de> Deserialize<'de> for ServeModelInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServeModelInput
Sourceimpl JsonSchema for ServeModelInput
impl JsonSchema for ServeModelInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServeModelInput
impl PartialEq for ServeModelInput
Sourceimpl Serialize for ServeModelInput
impl Serialize for ServeModelInput
impl StructuralPartialEq for ServeModelInput