ServeProcessAllocation

Struct ServeProcessAllocation 

pub struct ServeProcessAllocation {
Show 13 fields pub process: String, pub role: String, pub replica: u32, pub rank: u32, pub rank_count: u32, pub machine: String, pub devices: Vec<u32>, pub model_locator: Option<String>, pub endpoint: Option<EndpointAssignment>, pub ports: BTreeMap<String, EndpointAssignment>, pub cache: String, pub launch: AllocationLaunch, pub dependencies: Vec<String>,
}
One concrete process the control plane placed, supplied to RenderServe: its identity, rank, machine, devices, model locator, and allocated endpoints and named ports.

Fields

process: Stringrole: Stringreplica: u32rank: u32rank_count: u32machine: Stringdevices: Vec<u32>model_locator: Option<String>endpoint: Option<EndpointAssignment>ports: BTreeMap<String, EndpointAssignment>cache: Stringlaunch: AllocationLaunchdependencies: Vec<String>