pub struct ServeRoleInput {
pub id: String,
pub kind: ServeRoleKind,
pub replica_count: u32,
pub parallelism: Parallelism,
pub settings: BTreeMap<String, SettingValue>,
}Expand description
A requested serving role: its identity, kind, replica cardinality, and declared (not-yet-completed) parallelism and settings.
Fields
id: Stringkind: ServeRoleKindreplica_count: u32parallelism: Parallelismsettings: BTreeMap<String, SettingValue>Trait Implementations
Sourceimpl Clone for ServeRoleInput
impl Clone for ServeRoleInput
Sourcefn clone(&self) -> ServeRoleInput
fn clone(&self) -> ServeRoleInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServeRoleInput
impl Debug for ServeRoleInput
Sourceimpl<'de> Deserialize<'de> for ServeRoleInput
impl<'de> Deserialize<'de> for ServeRoleInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServeRoleInput
impl JsonSchema for ServeRoleInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServeRoleInput
impl PartialEq for ServeRoleInput
Sourceimpl Serialize for ServeRoleInput
impl Serialize for ServeRoleInput
impl StructuralPartialEq for ServeRoleInput