pub struct ServeRoleResult {
pub id: String,
pub kind: ServeRoleKind,
pub declared_replica_count: u32,
pub effective_replica_count: u32,
pub effective_settings: BTreeMap<String, SettingValue>,
pub effective_parallelism: Parallelism,
}Expand description
A role as the integration resolved it: preserved identity and cardinality with the complete effective settings and parallelism.
Fields
id: Stringkind: ServeRoleKinddeclared_replica_count: u32effective_replica_count: u32effective_settings: BTreeMap<String, SettingValue>effective_parallelism: ParallelismTrait Implementations
Sourceimpl Clone for ServeRoleResult
impl Clone for ServeRoleResult
Sourcefn clone(&self) -> ServeRoleResult
fn clone(&self) -> ServeRoleResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServeRoleResult
impl Debug for ServeRoleResult
Sourceimpl<'de> Deserialize<'de> for ServeRoleResult
impl<'de> Deserialize<'de> for ServeRoleResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServeRoleResult
impl JsonSchema for ServeRoleResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServeRoleResult
impl PartialEq for ServeRoleResult
Sourceimpl Serialize for ServeRoleResult
impl Serialize for ServeRoleResult
impl StructuralPartialEq for ServeRoleResult