pub struct ServerMetricsEndpointInput {
pub path: String,
pub port_name: Option<String>,
pub url: String,
}Expand description
The resolved server-metrics endpoint supplied to a measurement client.
Fields
path: Stringport_name: Option<String>url: StringTrait Implementations
Sourceimpl Clone for ServerMetricsEndpointInput
impl Clone for ServerMetricsEndpointInput
Sourcefn clone(&self) -> ServerMetricsEndpointInput
fn clone(&self) -> ServerMetricsEndpointInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServerMetricsEndpointInput
impl Debug for ServerMetricsEndpointInput
Sourceimpl<'de> Deserialize<'de> for ServerMetricsEndpointInput
impl<'de> Deserialize<'de> for ServerMetricsEndpointInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServerMetricsEndpointInput
Sourceimpl JsonSchema for ServerMetricsEndpointInput
impl JsonSchema for ServerMetricsEndpointInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ServerMetricsEndpointInput