pub struct ServerMetricsEndpointRequirement {
pub path: String,
pub port: Option<String>,
}Expand description
An integration-owned logical server-metrics endpoint.
Fields
path: Stringport: Option<String>Trait Implementations
Sourceimpl Clone for ServerMetricsEndpointRequirement
impl Clone for ServerMetricsEndpointRequirement
Sourcefn clone(&self) -> ServerMetricsEndpointRequirement
fn clone(&self) -> ServerMetricsEndpointRequirement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ServerMetricsEndpointRequirement
impl<'de> Deserialize<'de> for ServerMetricsEndpointRequirement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServerMetricsEndpointRequirement
Sourceimpl JsonSchema for ServerMetricsEndpointRequirement
impl JsonSchema for ServerMetricsEndpointRequirement
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ServerMetricsEndpointRequirement