pub struct SuppliedRenderInput {
pub source_path: String,
pub text: String,
pub sha256: String,
}Expand description
The original declared path plus the exact UTF-8 contents and digest the control plane supplies to an integration during final rendering.
Fields
source_path: Stringtext: Stringsha256: StringTrait Implementations
Sourceimpl Clone for SuppliedRenderInput
impl Clone for SuppliedRenderInput
Sourcefn clone(&self) -> SuppliedRenderInput
fn clone(&self) -> SuppliedRenderInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SuppliedRenderInput
impl Debug for SuppliedRenderInput
Sourceimpl<'de> Deserialize<'de> for SuppliedRenderInput
impl<'de> Deserialize<'de> for SuppliedRenderInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SuppliedRenderInput
Sourceimpl JsonSchema for SuppliedRenderInput
impl JsonSchema for SuppliedRenderInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SuppliedRenderInput
impl PartialEq for SuppliedRenderInput
Sourceimpl Serialize for SuppliedRenderInput
impl Serialize for SuppliedRenderInput
impl StructuralPartialEq for SuppliedRenderInput