pub struct ServeProcessAllocation {Show 13 fields
pub process: String,
pub role: String,
pub replica: u32,
pub rank: u32,
pub rank_count: u32,
pub machine: String,
pub devices: Vec<u32>,
pub model_locator: Option<String>,
pub endpoint: Option<EndpointAssignment>,
pub ports: BTreeMap<String, EndpointAssignment>,
pub cache: String,
pub launch: AllocationLaunch,
pub dependencies: Vec<String>,
}Expand description
One concrete process the control plane placed, supplied to RenderServe:
its identity, rank, machine, devices, model locator, and allocated
endpoints and named ports.
Fields
process: Stringrole: Stringreplica: u32rank: u32rank_count: u32machine: Stringdevices: Vec<u32>model_locator: Option<String>endpoint: Option<EndpointAssignment>ports: BTreeMap<String, EndpointAssignment>cache: Stringlaunch: AllocationLaunchdependencies: Vec<String>Trait Implementations
Sourceimpl Clone for ServeProcessAllocation
impl Clone for ServeProcessAllocation
Sourcefn clone(&self) -> ServeProcessAllocation
fn clone(&self) -> ServeProcessAllocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServeProcessAllocation
impl Debug for ServeProcessAllocation
Sourceimpl<'de> Deserialize<'de> for ServeProcessAllocation
impl<'de> Deserialize<'de> for ServeProcessAllocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ServeProcessAllocation
impl JsonSchema for ServeProcessAllocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServeProcessAllocation
impl PartialEq for ServeProcessAllocation
Sourceimpl Serialize for ServeProcessAllocation
impl Serialize for ServeProcessAllocation
impl StructuralPartialEq for ServeProcessAllocation