pub struct ServeProcessAllocation {
pub process_id: String,
pub role_id: String,
pub replica_id: String,
pub replica_index: u32,
pub rank: u32,
pub machine_id: String,
pub model_locator: String,
pub runtime_cache_root: String,
pub devices: Vec<u32>,
pub endpoint: EndpointAssignment,
pub ports: BTreeMap<String, EndpointAssignment>,
}Expand description
One concrete process the control plane placed, supplied to RenderServe:
its identity, rank, machine, devices, model locator, and allocated
endpoints and named ports.
Fields
process_id: Stringrole_id: Stringreplica_id: Stringreplica_index: u32rank: u32machine_id: Stringmodel_locator: Stringruntime_cache_root: Stringdevices: Vec<u32>endpoint: EndpointAssignmentports: BTreeMap<String, EndpointAssignment>Trait Implementations
Sourceimpl Clone for ServeProcessAllocation
impl Clone for ServeProcessAllocation
Sourcefn clone(&self) -> ServeProcessAllocation
fn clone(&self) -> ServeProcessAllocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServeProcessAllocation
impl Debug for ServeProcessAllocation
Sourceimpl<'de> Deserialize<'de> for ServeProcessAllocation
impl<'de> Deserialize<'de> for ServeProcessAllocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServeProcessAllocation
Sourceimpl JsonSchema for ServeProcessAllocation
impl JsonSchema for ServeProcessAllocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServeProcessAllocation
impl PartialEq for ServeProcessAllocation
Sourceimpl Serialize for ServeProcessAllocation
impl Serialize for ServeProcessAllocation
impl StructuralPartialEq for ServeProcessAllocation